diff lisp/gnus/mm-util.el @ 101165:a22ed49b5bef

Merge from gnus--devo--0 Revision: emacs@sv.gnu.org/emacs--devo--0--patch-1517
author Miles Bader <miles@gnu.org>
date Wed, 14 Jan 2009 07:51:26 +0000
parents a16e9f7c2536
children 73bff1db57b6
line wrap: on
line diff
--- a/lisp/gnus/mm-util.el	Wed Jan 14 03:50:46 2009 +0000
+++ b/lisp/gnus/mm-util.el	Wed Jan 14 07:51:26 2009 +0000
@@ -840,13 +840,16 @@
   "A table of the difference character between ISO-8859-X and ISO-8859-15.")
 
 (defcustom mm-coding-system-priorities
-  (if (boundp 'current-language-environment)
-      (let ((lang (symbol-value 'current-language-environment)))
-	(cond ((string= lang "Japanese")
-	       ;; Japanese users prefer iso-2022-jp to euc-japan or
-	       ;; shift_jis, however iso-8859-1 should be used when
-	       ;; there are only ASCII text and Latin-1 characters.
-	       '(iso-8859-1 iso-2022-jp iso-2022-jp-2 shift_jis utf-8)))))
+  (let ((lang (if (boundp 'current-language-environment)
+		  (symbol-value 'current-language-environment))))
+    (cond (;; XEmacs without Mule but with `file-coding'.
+	   (not lang) nil)
+	  ;; In XEmacs 21.5 it may be the one like "Japanese (UTF-8)".
+	  ((string-match "\\`Japanese" lang)
+	   ;; Japanese users prefer iso-2022-jp to euc-japan or
+	   ;; shift_jis, however iso-8859-1 should be used when
+	   ;; there are only ASCII text and Latin-1 characters.
+	   '(iso-8859-1 iso-2022-jp iso-2022-jp-2 shift_jis utf-8))))
   "Preferred coding systems for encoding outgoing messages.
 
 More than one suitable coding system may be found for some text.